Django-Ash
===========
Django Admin Theme based on `Datta Able
<https://github.com/codedthemes/datta-able-bootstrap-dashboard>`_.

.. image:: https://github.com/farajim25/django-ash/blob/main/docs/images/login.png
.. image:: https://github.com/farajim25/django-ash/blob/main/docs/images/index.png

Requirements
------------
* Django 3.0+


Installation
------------
.. code:: bash

    pip install django-ash

Add ``ash`` to top of ``INSTALLED_APPS``:

.. code:: python

    INSTALLED_APPS = [
        'ash',
        'django.contrib.admin',
        ...
    ]

